#!/usr/bin/env python
#=====================================================================
#
#               Python Scripts for CitcomS Version 3.0
#                  ---------------------------------
#
#                              Authors:
#          (c) California Institute of Technology 2008
#
#               Free for non-commercial academic use ONLY.
#      This program is distributed WITHOUT ANY WARRANTY whatsoever.
#
#=====================================================================
#
#  Copyright Jan 2008, by the California Institute of Technology.
#  ALL RIGHTS RESERVED. United States Government Sponsorship Acknowledged.
#
#=====================================================================
#
#=====================================================================
#=====================================================================

import sys, string, os, math, commands, random
import CitcomParser
import Core_Citcom, Core_Util
import Core_GMT, Core_File

Core_Citcom.verbose = True
Core_GMT.verbose = True


#====================================================================
#====================================================================

def usage():
    '''print usage message, and exit'''

    print '''xsect_plot.py plot_cfg_file
where:
  plot_cfg_file - name of a plotting .cfg file structured as follows.  Optional arguments are given in curly brackets.  Please also read the `notes' section after the template input file:

[All_Figures]
(arguments as below, but none are required.  This will override any settings in [Figure_X])

[Figure_A]
citcoms_pid=
time=
x=
field=visc/temp/phase/surf
if you just want to see the output xyz file of a field
{add_field=comp}
{contour=visc/temp/phase}
{overlay_velocity=true/false}
{velocity_scale=}
{velocity_increment=}


[Figure_B]
(arguments as above)

[Figure_C]
(arguments as above)

[Figure_D]
(arguments as above)


-----------------------------------
This module uses the core_* modules
-----------------------------------
'''

    sys.exit()


#=====================================================================
#	Builds dictionaries for each figure
# This gets called when you enter this script name + cfg file	
#=====================================================================
def main():
    print 'plot_collection_of_outputs.py'
    # Parse cmd line input for input plotting config file
    if len(sys.argv) != 2:
        usage()

    settings_file = sys.argv[1]
    # Read in settings into main dictionary
    settings = {}
    settings = Core_File.parse_control_file( settings_file )
    # Build individual figure dictionaries
    figa = {}
    figb = {}
    figc = {}
    figd = {}
    # Update figure dictionaries with global settings 
    get_figure_global_settings( figa )
    get_figure_global_settings( figb )
    get_figure_global_settings( figc )
    get_figure_global_settings( figd )
    # Merge figure dictionaries with local settings
    get_figure_a_settings( figa )
    get_figure_b_settings( figb )
    get_figure_c_settings( figc )
    get_figure_d_settings( figd )
    # Merge figure dictionaries with settings in *.cfg file
    # This will override defaults
    figa.update(settings['Figure_A'])
    figb.update(settings['Figure_B'])
    figc.update(settings['Figure_C'])
    figd.update(settings['Figure_D'])
    # Update figure dictionaries with All_Figure settings from config file
    # This will overwrite defined settings in the individual figure section
    figall = settings['All_Figures']
    figa.update( figall )
    figb.update( figall )
    figc.update( figall )
    figd.update( figall )
    # Make dictionary of page settings
    page_settings = {}
    get_page_settings( page_settings )
    ps_name(figa, figb, figc, figd, page_settings)
    # Merge figure dictionaries with page settings
    figa.update( page_settings )
    figb.update( page_settings )
    figc.update( page_settings )
    figd.update( page_settings )
    # Start page
    Core_GMT.start_page( page_settings )
    # Build figures
    build_figure( figa )
    build_figure( figb )
    build_figure( figc )
    build_figure( figd )
    # End page
    Core_GMT.end_page( page_settings )



# =====================================================================
#	PLOT Vectors using psvelo
# =====================================================================
def plot_psvelo( dict ):
    xy = dict['xy']
    print "============================="
    print "USING PSVELO"
    print "============================="
    print "Converting xyfile"
    print xy
    print "============================="
    ps = dict['ps']
    # command with required arguments
    cmd = 'psvelo velo.xy -Se1/1/1 -V ' % vars()
    cmd += '-J%s ' % dict['J']
    cmd += '-R%s ' % dict['R']
    print cmd
    # optional args
    if dict.get('B'): cmd += '-B%s ' % dict.get('B') 
    if dict.get('G'): cmd += '-G%s ' % dict.get('G') 
    if dict.get('K'): cmd += '-K%s ' % dict.get('K') 
    if dict.get('O'): cmd += '-O%s ' % dict.get('O') 
    if dict.get('W'): cmd += '-W%s ' % dict.get('W') 
    if dict.get('X'): cmd += '-X%s ' % dict.get('X') 
    if dict.get('Y'): cmd += '-Y%s ' % dict.get('Y')
    if dict.get('N'): cmd += '-N '  
    # Read velfile and convert to east and north components 
    velfile=open(xy,'r')
    fileread=velfile.readlines()
    outfile=open('velo.xy','w')
    for line in fileread:
        velline=line.split(' ')
        longt=velline[0]
        latt=velline[1]
        angle=velline[2]
        length=velline[3]
        #print "angle"
        #print angle
        #print "length"
        #print length
        anglen=float(angle)*math.pi/180.
        eastvel=float(length)*math.sin(anglen)
        northvel=float(length)*math.cos(anglen)
        #eastvel=float(length)*math.cos(anglen)
        #northvel=float(length)*math.sin(anglen)
        #print "easting"
        #print eastvel
        #print "northing"
        #print northvel
	# Make line entries
        newline=(longt+' '+latt+' '+str(eastvel)+' '+str(northvel)+'\n')
        outfile.write(newline)
    outfile.close()
    velfile.close()
    # Plot velocities using psvelo
    cmd += ' >> %(ps)s' % vars()
    print cmd
    os.system(cmd)
    return


# =====================================================================
# Converts the nodex and nodey (theta and fi) into lat long
# =====================================================================
def convert_node( dict ):
	r2d=float(57.2957795)
	d2r=float(0.0175)
	CMB_Depth=float(2891)
	a=str(dict['Age'])
	#Latitude
	if dict['x'] <> 'none':
		distance=(float(dict['theta_max'])-float(dict['theta_min']))/(float(dict['nodex']))
		theta=float(dict['theta_min'])+float(dict['x'])*distance
		latitude=float(90-(theta * r2d))
		dict['latitude']=latitude
	# Make and xy file for plotting location of slice in gmt
		longs=range(  int((float(dict['fi_min'])) *r2d) , int((float(dict['fi_max']))*r2d))
		print "latitude"
		print latitude
		print "latitude resolution"
		print distance
		SLat=open('latitude_line.xy',"w")
		for i in range(len(longs)):
			longit=int(longs[i])	
			SLat.write('%s %s\n' % (float(longit), latitude))
		SLat.close()
		#dict['xy'] ='latitude_line.xy'
		#os.system("cp latitiude_line.xy latitiude_sect.xy")
	else:
		dict['latitude']='none'
	#Longitude		
	if dict['y'] <> 'none':
		distance=(float(dict['fi_max'])-float(dict['fi_min']))/(float(dict['nodey']))
		fi=float(dict['fi_min'])+float(dict['y']) * distance
		longitude=float(fi * r2d)
		dict['longitude'] = longitude		
		lats=range(  90 - int((float(dict['theta_max']))*r2d) , 90 - int((float(dict['theta_min'])) *r2d))
		print "longitude"
		print longitude
		print "longitude resolution"
		print distance
		SLong=open('longitude_line.xy',"w")
		for i in range(len(lats)):
			latit=int(lats[i])	
			SLong.write('%s %s\n' % (float(longitude), latit))
		SLong.close()
		#os.system("cp longitude_line.xy longitude_line_"+a+".xy")
		#dict['xy'] ='longitude_line.xy'
	else:
		dict['longitude'] = 'none'
	if dict['z'] <> 'none':
		distance=CMB_Depth/(float(dict['nodez']))
		depth=int(( (float(dict['nodez'])) - (float(dict['z'])) ) * distance)
		print "map view"
		print "depth resolution"
		print distance
		dict['mapview'] = depth
	else:
		dict['mapview'] = 'none'
	return




#=====================================================================
#	Defines the name of the output ps file
#=====================================================================
def ps_name( figa, figb, figc, figd, page_settings ):
    """Determine output ps file name"""
    # final ps file name
    page_settings['ps'] = figa['field'] + figa['time'] + '_' \
                        + figb['field'] + figb['time'] + '_' \
                        + figc['field'] + figc['time'] + '_' \
                        + figd['field'] + figd['time'] \
                        + '.ps'
    return



#=====================================================================
#	Set standard plotting settings
#=====================================================================
def get_figure_global_settings( dict ):
    """Global settings for all figures"""
    # Set `global' grid parameters
    dict['grid_tension'] = '0.1'
    dict['grid_increment'] = '0.25/0.005'
    dict['y'] = 'none'
    dict['x'] = 'none'
    dict['z'] = 'none'
    dict['s'] = 'none'
    dict['h'] = 'none'
    dict['overlay_sectionx'] ='none'
    dict['overlay_sectiony'] ='none'
    dict['overlay_transition']='none'
    dict['width'] = '110'
    return


#=====================================================================
#	Reads in the settings for figure a
#	basically just positioning information
#=====================================================================
def get_figure_a_settings( dict ):
    """Settings for figure a"""
    # ///// FIGURE POSITION ///// #
    dict['X'] = 'a-0.45'
    dict['Y'] = 'a4.5'
    # ///// CPT SCALE BAR POSITION ///// #
    dict['D'] = '2.0/5.0/1.25/0.15h'
    #dict['D'] = '0.5/3.8/1.25/0.15h'
    # ///// LEGEND POSITION EG VELOCITY SCALE ///// #
    dict['pslegend_D'] = '-0.5/-1.0/4.8/1/BL'
    # positioning info for text string
    # need to concatenate text string to end
    # of this statement
    dict['text'] = '0.0 6.8 10 0 0 BL '
    return



#=====================================================================
#	Reads in the settings for figure b
#=====================================================================
def get_figure_b_settings( dict ):
    """Settings for figure b"""
    # ///// FIGURE POSITION ///// #
    dict['X'] = 'a5.25'
    dict['Y'] = 'a4.3'
    # ///// CPT SCALE BAR POSITION ///// #
    #dict['D'] = '5/3.8/1.25/0.15h'
    dict['D'] = '9.0/5.5/1.25/0.15'
    # ///// LEGEND POSITION EG VELOCITY SCALE ///// #
    #dict['pslegend_D'] = '5.34/1.75/2.2/0.24/BL'
    dict['pslegend_D'] = '5.2/-1.0/4.6/1/BL'
    # positioning info for text string
    # need to concatenate text string to end
    # of this statement
    dict['text'] = '5.1 6.8 10 0 0 BL '
    return



#=====================================================================
#	Reads in the settings for figure c
#=====================================================================
def get_figure_c_settings( dict ):
    "Settings for figure c"""
    # ///// FIGURE POSITION ///// #
    dict['X'] = 'a-0.45'
    dict['Y'] = 'a1.0'
    # ///// CPT SCALE BAR POSITION ///// #
    #dict['D'] = '0.5/-0.3/1.25/0.15h'
    dict['D'] = '2.0/1.2/1.25/0.15h'
    # ///// LEGEND POSITION EG VELOCITY SCALE ///// #
    dict['pslegend_D'] = '-0.5/-1.0/4.8/1/BL'
    # positioning info for text string
    # need to concatenate text string to end
    # of this statement
    dict['text'] = '0.0 2.7 10 0 0 BL '
    return



#=====================================================================
#	Reads in the settings for figure d
#=====================================================================
def get_figure_d_settings( dict ):
    "Settings for figure d"""
    # ///// FIGURE POSITION ///// #
    dict['X'] = 'a5.25'
    dict['Y'] = 'a0.7'
    # ///// CPT SCALE BAR POSITION ///// #
    dict['D'] = '9.0/2.0/1.25/0.15'
    #dict['D'] = '7.0/0.8/1.25/0.15h'
    # ///// LEGEND POSITION EG VELOCITY SCALE ///// #
    dict['pslegend_D'] = '5.2/-1.0/4.6/1/BL'
    #dict['pslegend_D'] = 'a7/0.0/5/1/BL'
    # positioning info for text string
    # need to concatenate text string to end
    # of this statement
    dict['text'] = '5.1 2.7 10 0 0 BL '
    return



#=====================================================================
#	Sets plotting page settings
#=====================================================================
def get_page_settings( dict ):
    """Settings for the page"""
    dict['page_orientation'] = 'landscape'
    dict['gmtset HEADER_FONT_SIZE'] = '14'
    # default font size for pslegend
    dict['gmtset ANOT_FONT_SIZE_PRIMARY'] = '12'
    return


#=====================================================================
#	Makes each figure from the dictionary (eg figa)
#=====================================================================
def build_figure( dict ):
    """Build a figure"""
    # Keep page open
    dict['K'] = '-K'
    dict['O'] = '-O'
    pid_file = dict['citcoms_pid']
    field = dict['field']
    # Parse CitcomS pidXXXX.cfg file
    d = Core_Citcom.parse_citcoms_cfg_file(pid_file)
    # Update figure dictionary with settings from pid_file
    dict.update(d)
    # Get dimensional time information
    runtime = Core_Citcom.get_runtime_from_step(pid_file,int(dict['time']))
    timemyr = round(runtime,2)
    Age=int(float(dict['start_age'])-timemyr)
    dict['Age'] = Age
    # what is the latitude or longitude of the section
    position=convert_node(dict)
    datafile = dict['datafile']
    # Make the dynamic topography file if surf is specified
    if field == 'surf':
        dict['s'] = 1
    # Make the surface heatflux file if surf is specified
    if field == 'heat':
        dict['h'] = 1
    # Set plot boundary frame, tick marks, and plot title
    # set title if a field is contoured
    if dict.get('contour') and dict['contour'] <> 'none':
        contour = dict['contour']
        string = "%(timemyr)s Myr - %(field)s with %(contour)s contours" % vars()
    # set title when no field is contoured
    else:
        string = "%(timemyr)s Myr -%(field)s" % vars()
    # Prepare for xslice (this ensures xslice is only called once per figure)
    if dict.get('contour') and dict['contour'] <> 'none':
        dict['field'] = dict['field'] + ',' + dict['contour']
    if dict.get('add_field') and dict['add_field'] <> 'none':
        dict['field'] = dict['field'] + ',' + dict['add_field']
    if dict.get('overlay_velocity') and dict['overlay_velocity'] == 'true':
        dict['field'] = dict['field'] + ',velocity'
        get_velocity_overlay( dict )
#    get_grid( dict )
    # create tmp xyz files For an x slice a y slice or a z slice 
    timestep=dict['time']
    # //////// PLOT NAMES ////////
    if dict['x'] <> 'none':
        Core_Citcom.xslice( dict )
        nameslice=dict['x']    
        lat_slice=str(int(dict['latitude']))
        string="%(Age)s Myr (step%(timestep)s) %(lat_slice)s deg (nx%(nameslice)s)  " % vars()
        B='a20f10/a0.1:."%(string)s":WesN' % vars()
    if dict['y'] <> 'none':
        Core_Citcom.yslice( dict )
        nameslice=dict['y']
        lon_slice=str(int(dict['longitude']))
        string="%(Age)s Myr (step%(timestep)s) %(lon_slice)s deg (ny%(nameslice)s) " % vars()
        B='a20f10/a0.1:."%(string)s":WesN' % vars()
    if dict['z'] <> 'none':
        if dict['datafile']=='AUS_2D':
            print "2D Model"
            reg2d='80/210/-45/45'
            dict['R']=reg2d
        Core_Citcom.zslice( dict )
        nameslice=dict['z']
        dep_slice=str(int(dict['mapview']))
        string="%(Age)s Myr (step%(timestep)s) %(dep_slice)skm (nz%(nameslice)s)" % vars()
        B='a20f10:."%(string)s":wESn' % vars()
    if dict['s'] <> 'none':
        Core_Citcom.Sfile(dict)
        nameslice=dict['s']
        string="%(Age)s Myr (step%(timestep)s) Topography km (nz%(nameslice)s)" % vars()
        B='a20f10:."%(string)s":wESn' % vars()
    if dict['h'] <> 'none':
        Core_Citcom.Hfile(dict)
        nameslice=dict['h']
        string="%(Age)s Myr (step%(timestep)s) Heatflux (nz%(nameslice)s)" % vars()
        B='a20f10:."%(string)s":wESn' % vars()
    dict['B'] = B
    dict.update({'name': nameslice})
    # Reset field to main grid image
    dict['field'] = field
    # create main image
    build_image( dict )
    # create cpt for main image
    get_field_cpt_settings( dict )
    # Use settings to make cpt
    Core_GMT.makecpt( dict )
    print "================================="
    print " Use settings to make cpt"
    print "================================="
    print " Color palette file "
    print dict['C']
    if dict['field'] == 'temp':
        dict['C'] = 'seis_hotreduced2.cpt'
    print dict['C']
    # plot the grid
    Core_GMT.grdimage( dict )
    if dict['field']=='comp':
	print "psxy composition field"
	dict['secondxy'] ='composition.xyz'
	dict['S'] ='c0.01'
	dict['col'] = dict['C']
	Core_GMT.psxy2( dict )
	# KEEP THE XY FILE PRODUCED BY THE COMP
	if dict['x'] and 'none' not in dict['x']:
		os.system("cp composition.xyz "+dict['field']+"_xsect"+dict['x']+"_"+str(dict['Age'])+".xyz")
	if dict['y'] and 'none' not in dict['y']:
		os.system("cp composition.xyz "+dict['field']+"_ysect"+dict['y']+"_"+str(dict['Age'])+".xyz")
	if dict['z'] and 'none' not in dict['z'] and 'none' in dict['y'] and 'none' in dict['x'] :
		os.system("cp composition.xyz "+dict['field']+"_zsect"+dict['z']+"_"+str(dict['Age'])+".xyz")
    if dict.get('overlay_velocity')  == 'true':
        dict['velocity_file']=dict['xy']
    # plot the scale bar
    get_scale_bar( dict )
    Core_GMT.psscale( dict )
    # bounding details no longer required for velocity or contour plotting
    del dict['B']
    # //////// PLOT VELOCITY VECTORS ////////
    # need to keep a record of the region to replace after vel plotting
    region=dict['R']
    if dict.get('overlay_velocity')  == 'true':
        #dict['R'] = dict['vel_region']
        print dict['R']
        #print "============================="
        #print " Randomly select velocities  "
        #print "============================="
        #Core_GMT.random_velocities( dict )
        print "============================="
        print " Set velocity vector region  "
        print "============================="
        make_vel_region( dict )
        dict['N'] = '-N'	
        #del dict['N']
	# Use psvelo instead
        if dict['x'] <> 'none':
            plot_psvelo( dict )
            os.system("cp velo.xy velo"+timestep+".xy")
        if dict['y'] <> 'none':
            plot_psvelo( dict )
        if dict['z'] <> 'none':
            #Core_GMT.psxy( dict )
            plot_psvelo( dict )
        if dict['s']  <> 'none':
            #Core_GMT.psxy( dict )
            plot_psvelo( dict )
        if dict['h']  <> 'none':
            #Core_GMT.psxy( dict )
            plot_psvelo( dict )
        del dict['N']
        del dict['G']
        del dict['velocity_file']
        dict['R']=region
        write_velocity_pslegend( dict )
        Core_GMT.pslegend( dict )
        print "============================="
        print "plotted the velocity legend"
        print "============================="
    # //////// PLOT LOCATION OF X SECTION ////////
    if dict.get('overlay_velocity') == 'true':
        del dict['S']
        del dict['xy']
    if dict.get('overlay_sectionx')  == 'true':
        dict['W']='6/0/255/255'
        dict['xy']='latitude_line.xy'
        Core_GMT.psxy( dict )
        print "==========================="
        print "plotted overlay section lat"
        print "==========================="
        # Also plot polygon on the plan section
        getpoly( dict)
        dict['W']='1/0/0/0'
        Core_GMT.psxy( dict )
        print "==========================="
        print "plotted plate polygon"
        print "==========================="
        plot_poly(dict)
    # //////// PLOT LOCATION OF Y SECTION ////////
    if dict['overlay_sectiony']  == 'true':
        dict['W']='6/0/255/255'
        dict['xy']='longitude_line.xy'
        Core_GMT.psxy( dict )
        print "==========================="
        print "plotted overlay section lat"
        print "==========================="
        # Also plot polygon on the plan section
        getpoly( dict)
        dict['W']='1/0/0/0'
        Core_GMT.psxy( dict )
        print "==========================="
        print "plotted plate polygon"
        print "==========================="
    # //////// PLOT LOCATION OF TRANSITION ZONE ////////
    if dict.get('overlay_transition') == 'true':
        dict['R'] = region
        print region
        Core_GMT.find_transition( dict )
        dict['W']='6/0/0/0'
        Core_GMT.psxy( dict )
        del dict['N']
        print "==========================="
        print "plotted the transition zone"
        print "==========================="
    # //////// PLOT COASTLINES ////////
    if dict['s'] <> 'none':
        getcoastlines(dict)
        dict['W']='1/0/0/0'
        Core_GMT.psxy( dict )
        print "==========================="
        print "plotted the coast lines"
        print "==========================="
    # //////// PLOT COASTLINES ////////
    if dict['h'] <> 'none':
        getcoastlines(dict)
        dict['W']='1/0/0/0'
        Core_GMT.psxy( dict )
        print "==========================="
        print "plotted the coast lines"
        print "==========================="
    # //////// PLOT COASTLINES ////////
    if dict['z'] <> 'none':
        getcoastlines(dict)
        dict['W']='1/0/0/0'
        Core_GMT.psxy( dict )
        print "==========================="
        print "plotted the coast lines"
        print "==========================="
    # contour info
    if dict.get('contour') and dict['contour'] <> 'none':
        dict['field'] = dict['contour']
        build_image ( dict )
        make_phase_cont_file( dict )
        #get_contour_cpt_settings( dict )
        #Core_GMT.makecpt( dict )
        Core_GMT.grdcontour( dict )
    dict['R'] = '0/11.0/0/8.5'
#        Core_GMT.pstext( dict )
    Core_GMT.pstext( dict )
    return


#=====================================================================
#	PLOT POLYGONS
#=====================================================================
def plot_poly(dict):
    #subductionzonesR='/home/lydia/GPLATES/Model8_Output/LINES_EQ/Polygons.subduction_boundaries_sR.'
    #subductionzonesL='/home/lydia/GPLATES/Model8_Output/LINES_EQ/Polygons.subduction_boundaries_sL.'
    #subductionzonesR='/home/lydia/Model_0.8.8_shiftedwest/OUTPUT_FEATUREDATA/LINES_EQ/Polygons.subduction_boundaries_sR.'
    #subductionzonesL='/home/lydia/Model_0.8.8_shiftedwest/OUTPUT_FEATUREDATA/LINES_EQ/Polygons.subduction_boundaries_sL.'
    subductionzonesR='/net/beno/raid2/alinah/Australia/GeneratingInput/Velocity/GPlatesOutput_SZ_23E/Polys_Rotated/Polygons.subduction_boundaries_sR.'
    subductionzonesL='/net/beno/raid2/alinah/Australia/GeneratingInput/Velocity/GPlatesOutput_SZ_23E/Polys_Rotated/Polygons.subduction_boundaries_sL.'     
    pid_file = dict['citcoms_pid']
    runtime = Core_Citcom.get_runtime_from_step(pid_file,int(dict['time']))
    timemyr = round(runtime,2)
    iage=int(float(dict['start_age'])-timemyr)
    age=str(iage)
    ps = dict['ps']
    subr=subductionzonesR+age+'.xy'
    subl=subductionzonesL+age+'.xy'
    os.system("psxy "+subr+" -R -O -K -J -X -Y -M -V -W3/0 -Sf0.2/0.07rt  -G0 -: >> "+ps) 
    os.system("psxy "+subl+" -R -O -K -J -X -Y -M -V -W3/0 -Sf0.2/0.07lt  -G0 -: >> "+ps) 
    return


#=====================================================================
#	Actually makes the image
#=====================================================================
def build_image( dict ):
    """build an image"""
    print "============================="
    print "Making a file from the field:"
    print dict['field']
    print "============================="
    # image xyz file name
    if dict['s'] <> 'none' or dict['h'] <> 'none':
	if dict['s'] <> 'none':
            dict['xyz_file'] = dict['surf_xy_file']
        if dict['h'] <> 'none':
            dict['xyz_file'] = dict['heat_xy_file']
    else:
        dict['xyz_file'] = dict['datafile'] + '.' \
                     + dict['time'] + '.' \
                     + dict['name'] + '.' \
                     + dict['field'] + '.' \
                     + 'xyz'
    # set -R from .xyz file
    Core_GMT.get_high_precision_region( dict )
    # create tmp grd file
    get_grid( dict )
    if dict['s'] <> 'none':
        dict['grid'] = Core_GMT.xyz2grd_smoothing( dict )
    if dict['h']<> 'none':
        dict['grid'] = Core_GMT.xyz2grd_smoothing( dict )	
    if dict['z'] <> 'none':
    	dict['grid'] = Core_GMT.xyz2grd_smoothing( dict )
        if dict['field']=='comp':
		print " ==========================================="
		print "Making the composition file composition.xyz"
		print " ==========================================="
		# FIND ZEROS
		lines=open(dict['xyz_file'],'r')
		liner=lines.readlines()
		comp0=open('comp0.xyz','w')	
		for l in liner:
			li=(l.split(' ')[0]+' '+l.split(' ')[1]+' 0.000 \n')		
			a=l.split(' ')[2]
			b=l.split(' ')[3]
			c=l.split(' ')[4]
			if '0.000' in a	and '0.000' in b and '0.000' in c:
				comp0.write(li)
		comp0.close()
		os.system("rm composition.xyz")	
		print "Making composition.xyz from "
		print 	dict['xyz_file']	
                os.system("awk '{if ($3>0.1) print($1, $2, 1) } ' "+dict['xyz_file']+" > comp1.xyz")
		os.system("awk '{if ($4>0.1) print($1, $2, 2) } ' "+dict['xyz_file']+" > comp2.xyz")
		os.system("awk '{if ($5>0.1) print($1, $2, 3) } ' "+dict['xyz_file']+" > comp3.xyz")
		os.system("cat comp0.xyz comp1.xyz comp2.xyz comp3.xyz > composition.xyz")
		os.system("rm comp0.xyz comp1.xyz comp2.xyz comp3.xyz")
		# DUMMY FOR BACKGROUND
		os.system("awk '{print($1, $2, 8) } ' composition.xyz > dummy.xyz ")
		dict['xyz_file']='dummy.xyz'
		dict['grid_max']='8'
		dict['grid'] = Core_GMT.xyz2grd( dict )
		dict['xyz_file']='composition.xyz' 
    else:
        if dict['field']=='phase':
            line=commands.getoutput('minmax '+ dict['xyz_file'])    
            vals=line.split('\t')[3]
            minphase=vals[1]
            maxphase=vals[3]
            store_grdmin=dict['grid_min']
            store_grdmax=dict['grid_max']
            dict['grid_max']=maxphase
            dict['grid_min']=minphase
    	    dict['grid'] = Core_GMT.xyz2grd( dict )
        else:
            if dict['field']=='comp':
		print " ==========================================="
		print "Making the composition file composition.xyz"
		print " ==========================================="
		# FIND ZEROS
		lines=open(dict['xyz_file'],'r')
		liner=lines.readlines()
		comp0=open('comp0.xyz','w')	
		for l in liner:
			li=(l.split(' ')[0]+' '+l.split(' ')[1]+' 0.000 \n')		
			a=l.split(' ')[2]
			b=l.split(' ')[3]
			c=l.split(' ')[4]
			if '0.000' in a	and '0.000' in b and '0.000' in c:
				comp0.write(li)
		comp0.close()
		os.system("rm composition.xyz")	
		print "Making composition.xyz from "
		print 	dict['xyz_file']	
                os.system("awk '{if ($3>0.1) print($1, $2, 1) } ' "+dict['xyz_file']+" > comp1.xyz")
		os.system("awk '{if ($4>0.1) print($1, $2, 2) } ' "+dict['xyz_file']+" > comp2.xyz")
		os.system("awk '{if ($5>0.1) print($1, $2, 3) } ' "+dict['xyz_file']+" > comp3.xyz")
		os.system("cat comp0.xyz comp1.xyz comp2.xyz comp3.xyz > composition.xyz")
		os.system("rm comp0.xyz comp1.xyz comp2.xyz comp3.xyz")
		# DUMMY FOR BACKGROUND
		os.system("awk '{print($1, $2, 8) } ' composition.xyz > dummy.xyz ")
		dict['xyz_file']='dummy.xyz'
		dict['grid_max']='8'
		dict['grid'] = Core_GMT.xyz2grd( dict )
		dict['xyz_file']='composition.xyz'
            else:
                dict['grid'] = Core_GMT.xyz2grd( dict )
    # fill dict with info on grid file; -R
    Core_GMT.grdinfo( dict )
    # Projection information
    if dict['x'] <> 'none':
    	ang = float(dict['west']) + ( float(dict['east']) - float(dict['west']) ) / 2
    	dict['J'] = 'Pa5/%(ang)s' % vars()
    if dict['y'] <> 'none':
	ang = float(dict['west']) + ( float(dict['east']) - float(dict['west']) ) / 2
    	dict['J'] = 'Pa5/%(ang)s' % vars()
    if dict['z'] <> 'none':
	dict['J'] = 'M8.5c'
    if dict['s'] <> 'none':
	dict['J'] = 'M8.5c'
    if dict['h'] <> 'none':
	dict['J'] = 'M8.5c'
    #if dict['closeup'] == 'yes':
     #   os.system('cp '+dict['grid']+ ' closeup.grd')
    return

#=====================================================================
#	Phase contour "color palette" really interval file
#=====================================================================

def make_phase_cont_file( dict ):
    cpt_field = dict['field']
    if cpt_field == 'phase':
        print "==============================="
        print "Making a phase contouring file"
        print "==============================="
        cpt_file = 'phase.int'
        writeclr=open(cpt_file,'w')
        if float(dict.get('clapeyron410')) > 0:
            print "===============================" 
            print " Phase transition at 410 km "
            print " Plotting Gamma 0.501 interval "  
            print "===============================" 
            cont1='0.501 C \n'
            writeclr.write(cont1)
        if float(dict.get('clapeyron670')) < 0:
            print "===============================" 
            print " Phase transition at 670 km " 
            print " Plotting Gamma 1.501 interval "
            print "===============================" 
            cont2='1.501 C \n'
            writeclr.write(cont2)
        writeclr.close()
    else:
        print "not a phase file"
    dict['C'] = cpt_file
    return

#=====================================================================
#	Contour colour palette
#=====================================================================

def get_contour_cpt_settings( dict ):
    """Get GMT cpt settings for the contoured field"""
    # before this function is called the code sets
    # dict['field'] = dict['contour']
    cpt_field = dict['field']
    del dict['C']
    del dict['cpt_cont']
    # cpt info for phase contour 
    if cpt_field == 'phase':
        dict['cpt_z0'] = '0'
        dict['cpt_z1'] = '1'
        dict['cpt_dz'] = '0.501'
        dict['A'] = '-'
        dict['W'] = 'cthin,black'
    # cpt info for temp contour
    elif cpt_field == 'temp':
        dict['cpt_z0'] = '0'
        dict['cpt_z1'] = '1'
        dict['cpt_dz'] = '0.2'
        dict['A'] = '+kwhite+s12'
        dict['W'] = 'athickest,green'
    # cpt info for contour
    elif cpt_field == 'comp':
        dict['cpt_z0'] = '0'
        dict['cpt_z1'] = '1'
        dict['cpt_dz'] = '0.2'
        dict['A'] = '+kwhite+s12'
        dict['W'] = 'athickest,green'
    # cpt info for visc contour
    elif cpt_field =='visc':
        dict['cpt_z0'] =  math.log10(float(dict['visc_min']))
        dict['cpt_z1'] = math.log10(float(dict['visc_max']))
        dict['cpt_dz'] = (dict['cpt_z1']-dict['cpt_z0'])/5
        dict['A'] = '+kwhite+s12'
        dict['W'] = 'athickest,green'
    return



#=====================================================================
#	Make velocity overlay
#=====================================================================
def get_velocity_overlay( dict ):
    """Settings for velocity overlay"""
    # ensure lower case v for correct velocity convention 
    # set xy file to plot
    dict['G'] ='0/0/0'
    if dict['x'] <> 'none':
	dict['S'] = 'v0.015i/0.06i/0.05i'
	pnode=dict['x']
    if dict['y'] <> 'none':
	dict['S'] = 'v0.015i/0.06i/0.05i'
	pnode=dict['y']
    if dict['z'] <> 'none':
	dict['S'] = 'V0.015i/0.06i/0.05i'
	pnode=dict['z']
    if dict['h'] <> 'none':
	dict['S'] = 'V0.015i/0.06i/0.05i'
        pnode=dict['h']
    if dict['s'] <> 'none':
	dict['S'] = 'V0.015i/0.06i/0.05i'
        pnode=dict['s']
    dict['xy'] = dict['datafile'] + '.' \
               + dict['time'] + '.' \
               + pnode + '.' \
               + 'velocity' + '.' \
               + 'xyz'
    return


#=====================================================================
#	Write Velocity Legend
#=====================================================================
def write_velocity_pslegend( dict ):
    '''Write pslegend info for velocity scale bar'''
    txt = ''
    velocity_scale = float(dict['velocity_scale'])
    velocity_scale = round(velocity_scale,1)
    datafile=dict['datafile']
    t=dict['Age']
    txt += '''# info line
L 9 Helvetica L %(datafile)s: %(datafile)s, time=%(t)s Ma
G 0.05i
D 0 1p,black,
''' % vars()
    txt += '''# velocity vector 
S 0.5 v 1.0/0.015/0.06/0.05 0/0/0 1,black 1.3i  Velocity scale: %(velocity_scale)s cm/yr
G 0.05i
D 0 1p,black,
''' % vars()
    #0.075c/0.3c/0.25c
    ps = dict['ps']
    # set args
    file_name = 'pslegend.txt' 
    file = open(file_name,'w')
    file.write('%s' % txt)
    file.close()
    dict['pslegend_file'] = file_name
    return


#=====================================================================
#
#=====================================================================
def get_grid( dict ):
    """determine grid properties based on input field"""
    field = dict['field']
    if field == 'phase':
        dict['grid_min'] = '0'
        dict['grid_max'] = '1'
    elif field == 'temp':
        dict['grid_min'] = '0'
        dict['grid_max'] = '1'
    elif field == 'comp':
        dict['grid_min'] = '0'
        dict['grid_max'] = '3'
    elif field == 'visc':
        dict['grid_min'] = math.log10(float(dict['visc_min']))
        dict['grid_max'] = math.log10(float(dict['visc_max']))
    elif field == 'surf':
        dict['grid_min'] = (float(-20000))
        dict['grid_max'] = (float(20000))
    elif field == 'heat':
        dict['grid_min'] = (float(-100))
        dict['grid_max'] = (float(100))
    return

#=====================================================================
#
#=====================================================================
def get_scale_bar( dict ):
    """get scale bar properties based on field"""
    field = dict['field']
    if field == 'phase':
        dict['B'] = 'a0.5/f0.1:' + field + ':'
    elif field == 'temp':
        dict['B'] = 'a0.5/f0.25:' + field + ':'
    elif field == 'comp':
        dict['B'] = 'a1/f0.25:' + field + ':'
    elif field == 'visc':
        dict['B'] = 'a1.0/f1:' + field + ':'
    elif field == 'surf':
        dict['B'] = 'a1000/f1:' + field + ':'
    elif field == 'heat':
        dict['B'] = 'a50/f1:' + field + ':'
    return


#=====================================================================
#
#=====================================================================
def get_field_cpt_settings( dict ):
    """Get GMT cpt settings for the field"""
    cpt_field = dict['field']
    # cpt info for phase field
    if cpt_field  == 'phase':
        dict['cpt_z0'] = '0'
        dict['cpt_z1'] = '1'
        dict['cpt_dz'] = '0.1'
        dict['C'] = 'polar'
        #dict['C'] = 'rainbow'
        dict['cpt_cont'] = ' '
    # cpt info for temp field
    elif cpt_field == 'temp':
        dict['cpt_z0'] = '0'
        dict['cpt_z1'] = '1'
        dict['cpt_dz'] = '0.1'
        #dict['C'] = 'jet'
        dict['C'] = 'rainbow'
        dict['cpt_cont'] = ' '
    # cpt info for comp field
    elif cpt_field == 'comp':
        dict['cpt_z0'] = '0'
        dict['cpt_z1'] = '3'
        dict['cpt_dz'] = '1'
        #dict['C'] = 'jet'
        dict['C'] = 'rainbow'
        dict['cpt_cont'] = ' '
    # cpt info for visc field
    elif cpt_field == 'visc':
        dict['cpt_z0'] = '-1'
        dict['cpt_z1'] = '2'
        dict['cpt_dz'] = '0.1'
        #dict['cpt_z0'] =  math.log10(float(dict['visc_min']))
        #dict['cpt_z1'] = math.log10(float(dict['visc_max']))
        #dict['cpt_dz'] = (dict['cpt_z1']-dict['cpt_z0'])/20.0
        dict['I'] = ' ' # invert scale
        dict['C'] = 'jet'
        dict['cpt_cont'] = ' '
    # cpt info for temp field
    elif cpt_field == 'surf':
        dict['cpt_z0'] = dict['z0']
        dict['cpt_z1'] = str(float(dict['z1'])+100)
        dict['cpt_dz'] = '100'
        dict['C'] = 'rainbow'
        dict['cpt_cont'] = ' '
    elif cpt_field == 'heat':
        dict['cpt_z0'] = dict['z0']
        dict['cpt_z1'] = str(float(dict['z1'])+1)
        dict['cpt_dz'] = '10'
        dict['C'] = 'rainbow'
        dict['cpt_cont'] = ' '
    return


#=====================================================================
#	Get the right polygons and plot them
#=====================================================================
def getpoly( dict ) :
    # Get dimensional time information
    pid_file = dict['citcoms_pid']
    runtime = Core_Citcom.get_runtime_from_step(pid_file,int(dict['time']))
    timemyr = round(runtime,2)
    iage=int(float(dict['start_age'])-timemyr)
    # Specify the rotation information
    pole= '0.0 225 37.5'
    equator='0.0 225 -37.5'
    rotpts='/net/beno/raid2/alinah/Australia/GeneratingInput/Temperature/RotateAgeFiles/rotpts'	
    #rotpts='/home/lydia/GPLATES/New_gplates/gplates_citcoms_utils/Rotations/rotpts'
    #pp_dir = "/home/lydia/GPLATES/Model8_Output/LINES"
    pp_dir = "/net/beno/raid2/alinah/Australia/GeneratingInput/Velocity/GPlatesOutput_SZ_23E/Polygons"
    #pp_dir = "/home/lydia/GPLATES/global_polygon_data/Model_0.8.6/Feature_Data"
	# FIND PREFIX OF PLATE POLYGON FILES
    filename1 = commands.getoutput('ls '+pp_dir+'/*.platepolygons.%d.xy'% (iage) )
    prefixpos = string.find(filename1,'.platepolygons.')
    prefix=filename1[0:prefixpos]
    pp_file = prefix+".platepolygons.%d.xy" % (iage)
	# Polygon file rotated back to the pole
    print "============================="
    print " Plate Polygon input file "
    print " from polar coordinates "
    print "============================="
    os.system("awk '{if ($0 !~/>/) print($2,"+'"\t"'+",  $1); else print("+'">"'+") } ' "+pp_file+" > readjusted_polys.xy ")
    os.system(rotpts+"  readjusted_polys.xy "+equator+" > out.xy")
    os.system("awk ' {if ($1 ~ /-/) print($1 +360,  $2); else print($1, $2) } ' out.xy > out2.xy ")
    print "============================="
    print "Rotated to the equator "
    print "============================="
    os.system("mv out2.xy Regional_poly_0.0.xy")
    pp_r_file='Regional_poly_0.0.xy'
    dict['xy'] = 'Regional_poly_0.0.xy'
    return

#=====================================================================
#	Get the right polygons and plot them
#=====================================================================
def getcoastlines( dict ) :
    # Get dimensional time information
    pid_file = dict['citcoms_pid']
    runtime = Core_Citcom.get_runtime_from_step(pid_file,int(dict['time']))
    timemyr = round(runtime,2)
    iage=int(float(dict['start_age'])-timemyr)
    print "====================================="
    print " Find dimensional time for coastlines"
    print "====================================="
    print iage
    # Specify the rotation information
    pole= '0.0 225 37.5'
    equator='0.0 225 -37.5'	
    rotpts='rotpts'
    coast_dir = "/home/lydia/GPLATES/ROTATED_COASTLINES/xyfile"
	# FIND PREFIX OF PLATE POLYGON FILES
    cs_file = commands.getoutput('ls '+coast_dir +'/CS_%d.xy'% (iage) )
    os.system("awk '{if ($0 !~/>/) print($1,"+'"\t"'+",  $2); else print("+'">"'+") } ' "+cs_file+" > readjusted_cs.xy ")
	# CS file rotated back to the pole
    print "====================================="
    print "Rotate the Coastlines to the equator "
    print "====================================="
    os.system(rotpts+"  readjusted_cs.xy "+equator+" > out.xy")
    print "====================================="
    os.system("mv out.xy Regional_cs_0.0.xy")
    cs_r_file='Regional_cs_0.0.xy'
    dict['xy'] = cs_r_file
    return

#=====================================================================
#	Remove vectors that are within X node points from edge
#	Set the variable dict['vel_region']
#=====================================================================
def make_vel_region( dict ):
    limit=0
    # Factor determines how many nodes in from min max you want to 
    # count where you will not be able to plot your velocity vectors
    factor=float(10)
    r2d = 180.0/math.pi
    CMB_Depth=float(2891)
    # Find resolution
    res_nodez=float(1-0.55)/ float(dict['nodez']) * factor
    radius_in=float(dict['radius_inner'])
    zmax=1-res_nodez
    zmin=radius_in+res_nodez
    res_nodex=(float(dict['theta_max'])-float(dict['theta_min']))/(float(dict['nodex']))
    lat_node_incr=res_nodex* r2d * factor
    lat_max=(90-(float(dict['theta_min'])* r2d)) - lat_node_incr
    lat_min=(90-(float(dict['theta_max'])* r2d)) + lat_node_incr
    res_nodey=(float(dict['fi_max'])-float(dict['fi_min']))/(float(dict['nodey']))
    long_node_incr=res_nodey* r2d * factor
    long_min=((float(dict['fi_min'])* r2d)) + long_node_incr
    long_max=((float(dict['fi_max'])* r2d)) - long_node_incr
    # Define Region
    if dict['y'] <> 'none':
        vel_region=str(lat_min)+'/'+str(lat_max)+'/'+str(zmin)+'/'+str(zmax)
        dict['vel_region'] = vel_region	
        dict['vxmin']=lat_min
        dict['vxmax']=lat_max
        dict['vymin']=zmin
        dict['vymax']=zmax
        if limit == 1:
            remove_edge_vels( dict )
            print "limiting the plotting of vectors"
    if dict['x'] <> 'none':
        vel_region=str(long_min)+'/'+str(long_max)+'/'+str(zmin)+'/'+str(zmax)
        dict['vel_region'] = vel_region
        dict['vxmin']=long_min
        dict['vxmax']=long_max
        dict['vymin']=zmin
        dict['vymax']=zmax
        if limit == 1:
            remove_edge_vels( dict )
            print "limiting the plotting of vectors"	
    if dict['z'] <> 'none':
        vel_region=str(long_min)+'/'+str(long_max)+'/'+str(lat_min)+'/'+str(lat_max)
        dict['vel_region'] = vel_region
        dict['vxmin']=long_min
        dict['vxmax']=long_max
        dict['vymin']=lat_min
        dict['vymax']=lat_max
        if limit == 1:
            remove_edge_vels( dict )
            print "limiting the plotting of vectors"
    if dict['s'] <> 'none':
        vel_region=str(long_min)+'/'+str(long_max)+'/'+str(lat_min)+'/'+str(lat_max)
        dict['vel_region'] = vel_region
        dict['vxmin']=long_min
        dict['vxmax']=long_max
        dict['vymin']=lat_min
        dict['vymax']=lat_max
        if limit == 1:
            remove_edge_vels( dict )
            print "limiting the plotting of vectors"
    if dict['h'] <> 'none':
        vel_region=str(long_min)+'/'+str(long_max)+'/'+str(lat_min)+'/'+str(lat_max)
        dict['vel_region'] = vel_region
        dict['vxmin']=long_min
        dict['vxmax']=long_max
        dict['vymin']=lat_min
        dict['vymax']=lat_max
        if limit == 1:
            remove_edge_vels( dict )
            print "limiting the plotting of vectors"
	return

#=====================================================================
#	Remove velocity vectors that are outside vel_region
#=====================================================================
def remove_edge_vels( dict ):
    velfile=dict['xy']
    infile=open(velfile,'r')
    info=commands.getoutput("wc -l "+velfile+"")
    length=info.split(' ')[0]
    edger=open('vel_sampled_edger.xy','w')
    for i in range(int(length)):
        line=infile.readline()
        values=line.split(' ')
        xval=float(values[0])
        yval=float(values[1])
        if xval > dict['vxmin'] and xval < dict['vxmax']:
            if yval  > dict['vymin'] and yval < dict['vymax']:
                edger.write(line)
    edger.close()
    infile.close()
    dict['xy'] = 'vel_sampled_edger.xy'
    return        




#=====================================================================
#	Piece below runs main function
#=====================================================================

if __name__ == "__main__":
    main()

#=====================================================================
#	CLEAN UP
#=====================================================================
os.system("rm tmp*.cpt")
#os.system("rm *.grd")
#os.system("rm *.xyz")
os.system("rm *.pslegend.txt")
os.system("rm out.xy Regional_poly_0.0.xy readjusted_polys.xy ")
os.system("rm vel_sampled_edger.xy sampled_velfile.xy")
os.system("rm readjusted_cs.xy Regional_cs_0.0.xy AUS_257_257_65_Jan08_slabs_surf.xys")
os.system("rm pslegend.txt")
os.system("rm transition_long.xy transition_lat.xy")
os.system("mv longitude_line.xy latitude_line.xy test_kara")


#end

