#!/bin/ksh
#Project: Extracting subsidence data along a transect at different time intervals
#Date: 01/06/09
#Author: Kara Matthews



#----This script is a modified version of Sample_Model_Subsidence.sh
#----It is to be used once the original data has been processed and the original file names have been changed
#----Everything else is the same


ts=1200

while (( $ts <= 1200 ))
    do

#----Loop through timesteps----

#----Variables----

xyz_file=Storage_Slab23E_HalfAsth/embd_surf_${ts}.xyz	#----REMEMBER TO CHANGE ALL PATHS!!!!!!!!!!!!
select_file=select_${ts}.dat
median_file=median_${ts}.dat 
output=${ts}.grd
grid_spacing=0.34
region=90/170/-40/40 
rotated_gridfile=rotated_${ts}.grd
finite_rotation=225/0/37.5 #----regional mesh has been rotated to the equator this will rotate it back

xy_file=Storage_Slab23E_HalfAsth/BHs_Gallagher_${ts}.xy	#CHANGE PATH
grdtrack_file=BH_subs_${ts}.dat


#----convert a selected region of .xyz data to gridded data using surface----

gmtselect $xyz_file -R$region -V > $select_file

blockmedian $select_file  -R$region -I$grid_spacing -V > $median_file 

surface $median_file -R$region -G$output -I$grid_spacing -V -C0.1 -T0.1

#----rotate gridded data back to correct position----

grdrotater $output -G$rotated_gridfile -T$finite_rotation -V

#----make image to check that data gridded correctly----

makecpt -Crainbow -T-3000/500/100 -Z -V > gridded_${ts}.cpt	

grdimage $rotated_gridfile -JM10 -Cgridded_${ts}.cpt -Ba30f30g30 -V > gridded${ts}.ps

#----Sample 2D grid file along a 1D track

grdtrack $xy_file -G$rotated_gridfile -V > $grdtrack_file

#----Want to compare the min and max z values of the gridded data to the grdtrack data to make sure 
#----that Surface hasn't interpolated to crazily 

minmax select_${ts}.dat BH_subs_${ts}.dat > minmax_comparison_${ts}.dat

#----Clean up a bit

mv embd_surf_${ts}.xyz BHs_Gallagher_${ts}.xy rotated_${ts}.grd gridded${ts}.ps Storage_Slab23E_HalfAsth
mv BH_subs_${ts}.dat minmax_comparison_${ts}.dat Model_subs_Slab23E_HalfAsth
rm ${ts}.grd gridded_${ts}.cpt select_${ts}.dat median_${ts}.dat

#----note that the boreholes are in alphabetical order as listed in Kerry Gallagher's data file 
#----(GSQ Eromanga follows Eromanga 1)

#----End file and loop to next timestep----

ts=$(($ts + 100))
 done
