#!/bin/ksh
#Project: Extracting subsidence data along a transect at different time intervals
#Date: 01/06/09
#Author: Kara Matthews



#This script is designed to convert .xyz files to .grd files
#.grd files are then rotated from the equator back to the their original positions
#The .grd files will then be used as input for grdtrack 


ts=0

while (( $ts <= 3200 ))
    do

#----Loop through timesteps----

#----Change file name to make things easier----
mv *_${ts}.xyz embd_surf_${ts}.xyz

#----Variables----

xyz_file=embd_surf_${ts}.xyz
select_file=select_${ts}.dat
median_file=median_${ts}.dat
output=${ts}.grd
grid_spacing=0.34
region=90/170/-40/40 
rotated_gridfile=rotated_${ts}.grd
finite_rotation=225/0/37.5 #----regional mesh has been rotated to the equator this will rotate it back

xy_file=BHs_Gallagher_${ts}.xy
grdtrack_file=BH_subs_${ts}.dat




#----convert a selected region of .xyz data to gridded data using surface----

gmtselect $xyz_file -R$region -V > $select_file

blockmedian $select_file  -R$region -I$grid_spacing -V > $median_file 

surface $median_file -R$region -G$output -I$grid_spacing -V -C0.1 -T0.1

#----rotate gridded data back to correct position----

grdrotater $output -G$rotated_gridfile -T$finite_rotation -V

#----make image to check that data gridded correctly----

makecpt -Crainbow -T-3000/500/100 -Z -V > gridded_${ts}.cpt	

grdimage $rotated_gridfile -JM10 -Cgridded_${ts}.cpt -Ba30f30g30 -V > gridded${ts}.ps

#----change file names of .xy data to make things easier and enable loop----

if [ $ts == 0 ]
	then mv BHs_Gallagher_140.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 100 ]
	then mv BHs_Gallagher_135.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 200 ]
	then mv BHs_Gallagher_130.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 300 ]
	then mv BHs_Gallagher_126.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 400 ]
	then mv BHs_Gallagher_123.xy BHs_Gallagher_${ts}.xy	
elif [ $ts == 500 ]
	then mv BHs_Gallagher_119.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 600 ]
	then mv BHs_Gallagher_117.xy BHs_Gallagher_${ts}.xy	
elif [ $ts == 700 ]
	then mv BHs_Gallagher_113.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 800 ]
	then mv BHs_Gallagher_109.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 900 ]
	then mv BHs_Gallagher_106.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1000 ]
	then mv BHs_Gallagher_103.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1100 ]
	then mv BHs_Gallagher_98.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1200 ]
	then mv BHs_Gallagher_93.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1300 ]
	then mv BHs_Gallagher_88.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1400 ]
	then mv BHs_Gallagher_84.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1500 ]
	then mv BHs_Gallagher_82.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1600 ]
	then mv BHs_Gallagher_79.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1700 ]
	then mv BHs_Gallagher_76.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1800 ]
	then mv BHs_Gallagher_73.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 1900 ]
	then mv BHs_Gallagher_68.xy BHs_Gallagher_${ts}.xy	
elif [ $ts == 2000 ]
	then mv BHs_Gallagher_65.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 2100 ]
	then mv BHs_Gallagher_63.xy BHs_Gallagher_${ts}.xy	
elif [ $ts == 2200 ]
	then mv BHs_Gallagher_61.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 2300 ]
	then mv BHs_Gallagher_58.xy BHs_Gallagher_${ts}.xy	
elif [ $ts == 2400 ]
	then mv BHs_Gallagher_56.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 2500 ]
	then mv BHs_Gallagher_53.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 2600 ]
	then mv BHs_Gallagher_50.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 2700 ]
	then mv BHs_Gallagher_46.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 2800 ]
	then mv BHs_Gallagher_42.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 2900 ]
	then mv BHs_Gallagher_39.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 3000 ]
	then mv BHs_Gallagher_34.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 3100 ]
	then mv BHs_Gallagher_30.xy BHs_Gallagher_${ts}.xy
elif [ $ts == 3200 ]
	then mv BHs_Gallagher_26.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 3300 ]
#	then mv BHs_Gallagher_13.xy BHs_Gallagher_${ts}.xy	
#elif [ $ts == 3400 ]
#	then mv BHs_Gallagher_7.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 3500 ]
#	then mv BHs_Gallagher_1.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 3600 ]
#	then mv BHs_Gallagher_7.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 3700 ]
#	then mv BHs_Gallagher_1.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 3800 ]
#	then mv BHs_Gallagher_39.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 3900 ]
#	then mv BHs_Gallagher_36.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 4000 ]
#	then mv BHs_Gallagher_32.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 4100 ]
#	then mv BHs_Gallagher_27.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 4200 ]
#	then mv BHs_Gallagher_23.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 4300 ]
#	then mv BHs_Gallagher_20.xy BHs_Gallagher_${ts}.xy
#elif [ $ts == 4400 ]
#	then mv BHs_Gallagher_16.xy BHs_Gallagher_${ts}.xy	
#elif [ $ts == 4500 ]
#	then mv BHs_Gallagher_11.xy BHs_Gallagher_${ts}.xy																																		
else
	echo "Hmmm something's wrong"
fi

#----Sample 2D grid file along a 1D track

grdtrack $xy_file -G$rotated_gridfile -V > $grdtrack_file

#----Want to compare the min and max z values of the gridded data to the grdtrack data to make sure 
#----that Surface hasn't interpolated to crazily 

minmax select_${ts}.dat BH_subs_${ts}.dat > minmax_comparison_${ts}.dat

#----REMEMBER TO CHANGE RUN NUMBER
#----Clean up a bit

mv embd_surf_${ts}.xyz BHs_Gallagher_${ts}.xy Storage_Slab23E_DoubleRa
mv BH_subs_${ts}.dat minmax_comparison_${ts}.dat Model_subs_Slab23E_DoubleRa
rm ${ts}.grd gridded_${ts}.cpt select_${ts}.dat median_${ts}.dat rotated_${ts}.grd gridded${ts}.ps 

#----note that the boreholes are in alphabetical order as listed in Kerry Gallagher's data file 
#----(GSQ Eromanga follows Eromanga 1)

#----End file and loop to next timestep----

ts=$(($ts + 100))
 done
