#!/bin/zsh

# This script creates tectonic subsidence curves for backstripped borehole data.
# Error is plotted as a shaded closed polygon around the avergage subsidence curve.

for file in *.xy
do
	
infile=$file
name=`basename $file .xy`
upper_bound=upper.xy
lower_bound=lower.xy
average_depth=average.xy
error_polygon=error_bounds.xy
TS_curve=TS_curve.xy
region=60/140/-1100/0
projection=X-12/10
boundary_annot=a20g20f20:"Time(Ma)":/a200g200f100:"Tectonic Subsidence (m)"::."${name}":WSne
pen=0.2/black
psfile=${name}.ps

#----Separate basement depth data in order to make error polygon 

awk '{print $1, -$3}' $infile > $upper_bound
awk '{print $1, -$4}' $infile > $lower_bound
awk '{print $1, -$2}' $infile > $average_depth

head -1 $upper_bound > aaa
tail -1 $upper_bound > ccc
sort -n -r $upper_bound > ddd

cat aaa $lower_bound ccc ddd > $error_polygon

#----Plot error polygon then overlay averaged curve 

#awk '{print $1}' $infile > age

#paste age $average_depth > $TS_curve

gmtset LABEL_FONT_SIZE 16p ANNOT_FONT_SIZE_PRIMARY 12p HEADER_FONT_SIZE 30p

psbasemap -R$region -J$projection -B$boundary_annot -X4 -K -V > $psfile 

psxy $error_polygon -R$region -J$projection -Ggrey -L -K -O -V >> $psfile
psxy $average_depth -R$region -J$projection -W$pen -K -O -V >> $psfile
psxy $average_depth -R$region -J$projection -Sc0.1 -Gblack -O -V >> $psfile

gmtset LABEL_FONT_SIZE 24p ANNOT_FONT_SIZE_PRIMARY 14p HEADER_FONT_SIZE 36p

#----Store graphs in separate file (make directory first)

mv $psfile Subs_Curves_140

rm aaa ccc ddd $upper_bound $lower_bound $average_depth $error_polygon

done