#!/bin/zsh

# This script creates tectonic subsidence curves for backstripped borehole data.
# Error is plotted as a shaded closed polygon around the avergage subsidence curve.

for file in *.xy
do
	
infile=$file
name=`basename $file .xy`
upper_bound=upper.xy
lower_bound=lower.xy
average_depth=average.xy
error_polygon=error_bounds.xy
TS_curve=TS_curve.xy
region=0/140/-2000/0
projection=X-14/12
boundary_annot=a20g20f20:"Time(Ma)":/a200g200f100:"Tectonic Subsidence (m)"::."${name}":WSne
pen=0.2/black
psfile=${name}.ps
TS_RUN1=RUN1_XYdata/model_$file		#---Change RUN number
TS_RUN2=RUN2_XYdata/model_$file
TS_RUN3=RUN3_XYdata/model_$file
TS_HalfRa=HalfRa_M99_XYdata/model_$file
TS_M99=M99_XYdata/model_$file
TS_DoubleRa=DoubleRa_XYdata/model_$file
TS_Warmer_Slab=Warmer_Slab_XYdata/model_$file
TS_Small_Slab=Small_Slab_XYdata/model_$file

#----Separate basement depth data in order to make error polygon 

awk '{print $1, -$3}' $infile > $upper_bound
awk '{print $1, -$4}' $infile > $lower_bound
awk '{print $1, -$2}' $infile > $average_depth

head -1 $upper_bound > aaa
tail -1 $upper_bound > ccc
sort -n -r $upper_bound > ddd

cat aaa $lower_bound ccc ddd > $error_polygon

#----Plot error polygon then overlay averaged curve 

#awk '{print $1}' $infile > age

#paste age $average_depth > $TS_curve

gmtset LABEL_FONT_SIZE 16p ANNOT_FONT_SIZE_PRIMARY 12p HEADER_FONT_SIZE 30p


psxy $error_polygon -R$region -J$projection -Ggrey -X4 -L -K -V > $psfile
psxy $average_depth -R$region -J$projection -W$pen -K -O -V >> $psfile
psxy $average_depth -R$region -J$projection -Sc0.1 -Gblack -K -O -V >> $psfile

#----Plot modelled TS.
#psxy $TS_RUN1 -R -J -W0.2/blue -K -O -V >> $psfile
#psxy $TS_RUN2 -R -J -W0.2/155/48/255 -K -O -V >> $psfile	#PURPLE
psxy $TS_RUN3 -R -J -W0.2/237/145/33 -K -O -V >> $psfile	#ORANGE
#psxy $TS_HalfRa -R -J -W0.2/green -K -O -V >> $psfile	
psxy $TS_M99 -R -J -W0.2/red -K -O -V >> $psfile
#psxy $TS_DoubleRa -R -J -W0.2/0/205/205 -K -O -V >> $psfile	#CYAN
#psxy $TS_Warmer_Slab -R -J -W0.2/255/20/147 -K -O -V >> $psfile	#PINK
#psxy $TS_Small_Slab -R -J -W0.2/139/69/19 -K -O -V >> $psfile	#BROWN
psbasemap -R$region -J$projection -B$boundary_annot -O -V >> $psfile 

gmtset LABEL_FONT_SIZE 24p ANNOT_FONT_SIZE_PRIMARY 14p HEADER_FONT_SIZE 36p

#----Store graphs in separate file (make directory first)
 
mv $psfile Subs_Curves_with_model_TS_curves/RUN3	#---Change RUN number
rm aaa ccc ddd $upper_bound $lower_bound $average_depth $error_polygon

done
